==> jc-1.4.0.tar.gz: soot/baf/internal/BInterfaceInvokeInst.h <==
// public class soot.baf.internal.BInterfaceInvokeInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 9eae4bbac6711e7a soot_baf_internal_AbstractInvokeInst
// @dep_class b15e6a8452190c8c soot_baf_internal_BInterfaceInvokeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInvokeInst

#include "soot/baf/internal/AbstractInvokeInst.h"

#ifndef _JC_soot_baf_internal_BInterfaceInvokeInst_H_
#define _JC_soot_baf_internal_BInterfaceInvokeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$sub_refs	_jc_soot_baf_internal_BInterfaceInvokeInst$sub_refs;
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$sub_nonrefs	_jc_soot_baf_internal_BInterfaceInvokeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$refs	_jc_soot_baf_internal_BInterfaceInvokeInst$refs;
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$nonrefs	_jc_soot_baf_internal_BInterfaceInvokeInst$nonrefs;
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$object	_jc_soot_baf_internal_BInterfaceInvokeInst$object;

typedef const struct _jc_soot_baf_internal_BInterfaceInvokeInst$vmethods	_jc_soot_baf_internal_BInterfaceInvokeInst$vmethods;
typedef const struct _jc_soot_baf_internal_BInterfaceInvokeInst$vtable	_jc_soot_baf_internal_BInterfaceInvokeInst$vtable;
typedef const struct _jc_soot_baf_internal_BInterfaceInvokeInst$vtype	_jc_soot_baf_internal_BInterfaceInvokeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BInterfaceInvokeInst$method$_init$d745e6fbf60e11d4(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_soot_SootMethod$object *, jint);

// Virtual methods
extern void _jc_soot_baf_internal_BInterfaceInvokeInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BInterfaceInvokeInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
extern jint _jc_soot_baf_internal_BInterfaceInvokeInst$method$getArgCount$1f92859ec5d6de26(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
extern jint _jc_soot_baf_internal_BInterfaceInvokeInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
extern jint _jc_soot_baf_internal_BInterfaceInvokeInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BInterfaceInvokeInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BInterfaceInvokeInst$method$getParameters$264df409c6a640fb(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
extern void _jc_soot_baf_internal_BInterfaceInvokeInst$method$getParameters$7ca7e2a5895cbf14(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_object *);
extern void _jc_soot_baf_internal_BInterfaceInvokeInst$method$setArgCount$322fad25e07d2313(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getArgCount$1f92859ec5d6de26;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getParameters$264df409c6a640fb;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getParameters$7ca7e2a5895cbf14;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$setArgCount$322fad25e07d2313;

// Virtual methods structure
struct _jc_soot_baf_internal_BInterfaceInvokeInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
	jint	(*getArgCount$1f92859ec5d6de26)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
	struct _jc_java_lang_String$object	*(*getParameters$264df409c6a640fb)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *);
	void	(*getParameters$7ca7e2a5895cbf14)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_object *);
	void	(*setArgCount$322fad25e07d2313)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, jint);
};

// Vtable
struct _jc_soot_baf_internal_BInterfaceInvokeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractInvokeInst$vmethods	soot_baf_internal_AbstractInvokeInst;
	_jc_soot_baf_internal_BInterfaceInvokeInst$vmethods	soot_baf_internal_BInterfaceInvokeInst;
};

// Vtype
struct _jc_soot_baf_internal_BInterfaceInvokeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BInterfaceInvokeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BInterfaceInvokeInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BInterfaceInvokeInst$refs {
    _jc_soot_baf_internal_BInterfaceInvokeInst$sub_refs	soot_baf_internal_BInterfaceInvokeInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_refs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BInterfaceInvokeInst$sub_nonrefs {
	jint	argCount;
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BInterfaceInvokeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_nonrefs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_BInterfaceInvokeInst$sub_nonrefs	soot_baf_internal_BInterfaceInvokeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BInterfaceInvokeInst$object {
	_jc_soot_baf_internal_BInterfaceInvokeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BInterfaceInvokeInst$vtype	*vtype;
	_jc_soot_baf_internal_BInterfaceInvokeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BInterfaceInvokeInst$vtype _jc_soot_baf_internal_BInterfaceInvokeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BInterfaceInvokeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BInterfaceInvokeInst$class_object;

#endif	/* _JC_soot_baf_internal_BInterfaceInvokeInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BInterfaceInvokeInst.h <==
// public class soot.baf.internal.BInterfaceInvokeInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 9eae4bbac6711e7a soot_baf_internal_AbstractInvokeInst
// @dep_class b15e6a8452190c8c soot_baf_internal_BInterfaceInvokeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInvokeInst

#include "soot/baf/internal/AbstractInvokeInst.h"

#ifndef _JC_soot_baf_internal_BInterfaceInvokeInst_H_
#define _JC_soot_baf_internal_BInterfaceInvokeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$sub_refs	_jc_soot_baf_internal_BInterfaceInvokeInst$sub_refs;
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$sub_nonrefs	_jc_soot_baf_internal_BInterfaceInvokeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$refs	_jc_soot_baf_internal_BInterfaceInvokeInst$refs;
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$nonrefs	_jc_soot_baf_internal_BInterfaceInvokeInst$nonrefs;
typedef struct _jc_soot_baf_internal_BInterfaceInvokeInst$object	_jc_soot_baf_internal_BInterfaceInvokeInst$object;

typedef const struct _jc_soot_baf_internal_BInterfaceInvokeInst$vmethods	_jc_soot_baf_internal_BInterfaceInvokeInst$vmethods;
typedef const struct _jc_soot_baf_internal_BInterfaceInvokeInst$vtable	_jc_soot_baf_internal_BInterfaceInvokeInst$vtable;
typedef const struct _jc_soot_baf_internal_BInterfaceInvokeInst$vtype	_jc_soot_baf_internal_BInterfaceInvokeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BInterfaceInvokeInst$method$_init$d745e6fbf60e11d4(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_soot_SootMethod$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BInterfaceInvokeInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BInterfaceInvokeInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BInterfaceInvokeInst$method$getArgCount$1f92859ec5d6de26(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BInterfaceInvokeInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BInterfaceInvokeInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BInterfaceInvokeInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BInterfaceInvokeInst$method$getParameters$264df409c6a640fb(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_BInterfaceInvokeInst$method$getParameters$7ca7e2a5895cbf14(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_BInterfaceInvokeInst$method$setArgCount$322fad25e07d2313(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getArgCount$1f92859ec5d6de26;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getParameters$264df409c6a640fb;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$getParameters$7ca7e2a5895cbf14;
extern _jc_method _jc_soot_baf_internal_BInterfaceInvokeInst$method_info$setArgCount$322fad25e07d2313;

// Virtual methods structure
struct _jc_soot_baf_internal_BInterfaceInvokeInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
	jint	(*getArgCount$1f92859ec5d6de26)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getParameters$264df409c6a640fb)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *) _JC_JCNI_ATTR;
	void	(*getParameters$7ca7e2a5895cbf14)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setArgCount$322fad25e07d2313)(_jc_env *, struct _jc_soot_baf_internal_BInterfaceInvokeInst$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BInterfaceInvokeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractInvokeInst$vmethods	soot_baf_internal_AbstractInvokeInst;
	_jc_soot_baf_internal_BInterfaceInvokeInst$vmethods	soot_baf_internal_BInterfaceInvokeInst;
};

// Vtype
struct _jc_soot_baf_internal_BInterfaceInvokeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BInterfaceInvokeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BInterfaceInvokeInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BInterfaceInvokeInst$refs {
    _jc_soot_baf_internal_BInterfaceInvokeInst$sub_refs	soot_baf_internal_BInterfaceInvokeInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_refs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BInterfaceInvokeInst$sub_nonrefs {
	jint	argCount;
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BInterfaceInvokeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_nonrefs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_BInterfaceInvokeInst$sub_nonrefs	soot_baf_internal_BInterfaceInvokeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BInterfaceInvokeInst$object {
	_jc_soot_baf_internal_BInterfaceInvokeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BInterfaceInvokeInst$vtype	*vtype;
	_jc_soot_baf_internal_BInterfaceInvokeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BInterfaceInvokeInst$vtype _jc_soot_baf_internal_BInterfaceInvokeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BInterfaceInvokeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BInterfaceInvokeInst$class_object;

#endif	/* _JC_soot_baf_internal_BInterfaceInvokeInst_H_ */
